@@ -6,8 +6,11 @@
                      ...) { 
   
   FitMultinomial         <- function(true,dat){
-    true[true == 0] <- 1
-    return(sum(dat*log(true)))
+    temp <- dat*log10(true); 
+    if (sum(is.na(temp)) > 0) {
+      
+      return(-Inf);
+    } else { return(sum(temp));}
   }
   
   count <- 0
