@@ -19,23 +19,23 @@ print.Full_PAFit_result <- function(x,...){
   
   if (mode == 0 || mode == 2) {
     if (object_estimate_result$auto_lambda == TRUE) {
-      cat("Estimated r parameter: ", object_estimate_result$ratio,"\n");
-    } else cat("Lambda used: ", object_estimate_result$lambda,"\n");
+      cat("Selected r parameter:", object_estimate_result$ratio,"\n");
+    } else cat("Lambda used:", object_estimate_result$lambda,"\n");
   }
   if (mode == 1 || mode == 2)
-    cat("Estimated s parameter:",object_estimate_result$shape,"\n")
+    cat("Selected s parameter:",object_estimate_result$shape,"\n")
   if (mode == 0 || mode == 2)
-    cat("Estimated attachment exponent: ",object_estimate_result$alpha,"\n");
+    cat("Estimated attachment exponent:",object_estimate_result$alpha,"\n");
   if (mode == 0 || mode == 2) {
     if (object_estimate_result$ci[1] == "N") {
-      cat("No possible confidence interval for the estimated attachment exponent.\n");
+      cat("No possible interval for the estimated attachment exponent.\n");
     } else if (object_estimate_result$mode_f != "Log_linear") {
-      cat("Two-sigma confidence interval of the attachment exponent: (", object_estimate_result$ci[1], ",", 
-          object_estimate_result$ci[2],")\n");
+      cat("Attachment exponent ","\u00B1", " 2 s.d.", ": (", object_estimate_result$ci[1], ",", 
+          object_estimate_result$ci[2],")\n",sep = "");
     }
     else {
-      cat("Two-sigma confidence interval of the attachment exponent: (", object_estimate_result$ci[1], ",", 
-          object_estimate_result$ci[2],")\n");  
+      cat("Attachment exponent ","\u00B1", " 2 s.d.", ": (", object_estimate_result$ci[1], ",", 
+          object_estimate_result$ci[2],")\n",sep = "");  
     }
   }
 }
\ No newline at end of file
