@@ -1,6 +1,6 @@
 library(PAFit)
 
-net  <- generate_net(N = 50, m = 10, mode = 1, shape = 100, rate = 100, 
+net  <- generate_net(N = 50, m = 10, mode = 1, s = 100, 
                      no_new_node_step = NULL)
 
 
